==> enterprisemodules-db2_config-0.3.0.tar.gz: enterprisemodules-db2_config-0.3.0/lib/puppet_x/enterprisemodules/db2/sql_command.rb <==
# frozen_string_literal: true

#
# See the file "LICENSE" for the full license governing this code.
#
require 'puppet_x/enterprisemodules/db2/command'
require 'base64'

module PuppetX
  module EnterpriseModules
    module Db2
      # docs
      class SqlCommand < PuppetX::EnterpriseModules::Db2::Command
        include EasyType::Helpers

        SQL_VALID_OPTIONS ||= [
          :instance,
          :database,
          :schema,
          :username,
          :password,
          :timeout,
          :parse,
          :failonfail
        ].freeze

        def initialize(options = {})
          super("#{File.dirname(__FILE__)}/execute_sql.rb", options, SQL_VALID_OPTIONS)
          @parse      = options.fetch(:parse, nil)
          @failonfail = options.fetch(:failonfail, true)
        end

        def execute(arguments)
          options = { :failonfail => @failonfail, :combine => true }
          value = ''
          within_time(@timeout) do
            value = execute_on_database(arguments, options)
          end
          value
        end

        def execute_on_database(arguments, options)
          Puppet.debug "sql_command.rb: Executing #{@command} command: export #{arguments} on #{@instance} and database #{@database}"
          fail 'No windows support yet' if Puppet::Util::Platform.windows?

          # We encode to support passing all sorts of characters to the exec
          encoded_arguments = Base64.encode64(arguments)
          results = Puppet::Util::Execution.execute(command_string("#{@instance} #{@database} '#{encoded_arguments}' #{@username} #{@password}"), options)
          if results[0..2] != '---'
            Puppet.debug "execute on database failed with output: #{results}"
            throw(:error_in_query, nil)
          end
          YAML.safe_load(results, [Symbol]).collect { |r| EasyType::Helpers::InstancesResults[r] }
        end
      end
    end
  end
end

==> enterprisemodules-db2_config-0.4.0.tar.gz: enterprisemodules-db2_config-0.4.0/lib/puppet_x/enterprisemodules/db2/sql_command.rb <==
# frozen_string_literal: true

#
# See the file "LICENSE" for the full license governing this code.
#
require 'puppet_x/enterprisemodules/db2/command'
require 'base64'

module PuppetX
  module EnterpriseModules
    module Db2
      # docs
      class SqlCommand < PuppetX::EnterpriseModules::Db2::Command
        include EasyType::Helpers

        SQL_VALID_OPTIONS ||= [
          :instance,
          :database,
          :schema,
          :username,
          :password,
          :timeout,
          :parse,
          :failonfail
        ].freeze

        def initialize(options = {})
          super("#{File.dirname(__FILE__)}/execute_sql.rb", options, SQL_VALID_OPTIONS)
          @parse      = options.fetch(:parse, nil)
          @failonfail = options.fetch(:failonfail, true)
        end

        def execute(arguments)
          options = { :failonfail => @failonfail, :combine => true }
          value = ''
          within_time(@timeout) do
            value = execute_on_database(arguments, options)
          end
          value
        end

        def execute_on_database(arguments, options)
          Puppet.debug "sql_command.rb: Executing #{@command} command: sql #{arguments} on #{@instance} and database #{@database}"
          fail 'No windows support yet' if Puppet::Util::Platform.windows?

          # We encode to support passing all sorts of characters to the exec
          encoded_arguments = Base64.encode64(arguments)
          results = Puppet::Util::Execution.execute(command_string("#{@instance} #{@database} '#{encoded_arguments}' #{@username} #{@password}"), options)
          if results[0..2] != '---'
            Puppet.debug "execute on database failed with output: #{results}"
            throw(:error_in_query, nil)
          end
          YAML.safe_load(results, [Symbol]).collect { |r| EasyType::Helpers::InstancesResults[r] }
        end
      end
    end
  end
end
